==> boo-0.7.8.2559-src.zip: src/Boo.Lang.Compiler/CompilerWarningCollection.cs <==
﻿#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

using System;
using System.Text;
using Boo.Lang;
using Boo.Lang.Compiler.Ast;

namespace Boo.Lang.Compiler
{
	/// <summary>
	/// Compiler errors.
	/// </summary>
	[EnumeratorItemType(typeof(CompilerWarning))]
	public class CompilerWarningCollection : Boo.Lang.Compiler.Util.MarshalByRefCollectionBase
	{
		public CompilerWarningCollection()
		{
		}

		public CompilerWarning this[int index]
		{
			get
			{
				return (CompilerWarning)InnerList[index];
			}
		}

		public void Add(CompilerWarning error)
		{
			if (null == error)
			{
				throw new ArgumentNullException("error");
			}
			InnerList.Add(error);
		}		
		
		override public string ToString()
		{
			return Boo.Lang.Builtins.join(InnerList, "\n");
		}		
	}
}

==> boo-0.9.1.3287-src.zip: src/Boo.Lang.Compiler/CompilerWarningCollection.cs <==
﻿#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

using System;

namespace Boo.Lang.Compiler
{
	public class CompilerWarningEventArgs : CancellableEventArgs
	{
		private readonly CompilerWarning _warning;

		public CompilerWarningEventArgs(CompilerWarning warning)
		{
			_warning = warning;
		}

		public CompilerWarning Warning
		{
			get { return _warning;  }
		}
	}

	/// <summary>
	/// Compiler errors.
	/// </summary>
	public class CompilerWarningCollection : List<CompilerWarning>
	{
		public event EventHandler<CompilerWarningEventArgs> Adding;

		public CompilerWarningCollection()
		{
		}

		override public List<CompilerWarning> Add(CompilerWarning warning)
		{
			if (OnAdding(warning))
			{
				return base.Add(warning);
			}
			return this;
		}

		protected bool OnAdding(CompilerWarning warning)
		{
			EventHandler<CompilerWarningEventArgs> adding = Adding;
			if (null == adding)
				return true;
			CompilerWarningEventArgs args = new CompilerWarningEventArgs(warning);
			adding(this, args);
			return !args.IsCancelled;
		}

		override public string ToString()
		{
			return Boo.Lang.Builtins.join(this, "\n");
		}		
	}
}
